# Time Ordered Astrophysics Scalable Tools

TOAST is a [software framework](https://en.wikipedia.org/wiki/Software_framework) for
simulating and processing timestream data collected by telescopes. Telescopes which
collect data as timestreams rather than images give us a unique set of analysis
challenges. Detector data usually contains noise which is correlated in time as well as
sources of correlated signal from the instrument and the environment. Large pieces of
data must often be analyzed simultaneously to extract an estimate of the sky signal.

## Documentation

See the full documentation here:

https://toast-cmb.readthedocs.io/en/latest/

![Build Status](https://github.com/hpc4cmb/toast/workflows/Run%20Test%20Suite/badge.svg?branch=master)
